/**
 * @file
 * Attaches behaviors for Drupal's active link marking.
 */
(function ($, Drupal, drupalSettings) {

  var ajaxSettings = {
    url: '/exit-survey/form',
    httpMethod: 'GET',
  };

  var exitSurvey = Drupal.ajax(ajaxSettings);

  const surveyIsSubmitted = function () {
    return localStorage.getItem('Drupal.exit_survey.submitted') === '';
  }

  function setSurverySubmitted() {
    localStorage.setItem('Drupal.exit_survey.submitted', '');
}

  const surveyIsOpen = function () {
    const stop = $('.ui-dialog-content').length;
    return Boolean(stop);
  }

  const userIsLoggedIn = function () {
    return drupalSettings.user.uid !== 0;
  }

  const isTouchDevice = function () {
  return (('ontouchstart' in window) ||
     (navigator.maxTouchPoints > 0) ||
     (navigator.msMaxTouchPoints > 0));
}

  // This command will remove this Ajax object from the page.
  exitSurvey.commands.destroyObject = function (ajax, response, status) {
    Drupal.ajax.instances[this.instanceIndex] = null;
  };

  if (!userIsLoggedIn()) {
    document.addEventListener('mouseout', (event) => {
      if (!event.toElement && !event.relatedTarget) {
        if (!surveyIsOpen() && !surveyIsSubmitted()) {
          setTimeout(() => {
            exitSurvey.execute();
          }, 100);
        }
      }
    });

    function myScrollSpeedFunction(event) {
      const delta = my_scroll();
      if(delta < -80){
        $(document).off('scroll', myScrollSpeedFunction);
        if (!surveyIsOpen() && !surveyIsSubmitted()) {
          setTimeout(() => {
            exitSurvey.execute();
          }, 100);
        }
      }
    }

    var my_scroll = (() => {
      let last_position, new_position, timer, delta, delay = 50;

      function clear() {
        last_position = null;
        delta = 0;
      }

      clear();
      return () => {
        new_position = window.scrollY;
        if (last_position != null){
          delta = new_position - last_position;
        }

        last_position = new_position;
        clearTimeout(timer);

        timer = setTimeout(clear, delay);

        return delta;
      };
    })()

    if (isTouchDevice()) {
      $(document).on('scroll', myScrollSpeedFunction);
    }

  }

  $(window).on('dialog:beforeclose', (e, dialog, $element) => {
    setSurverySubmitted();
  });

})(jQuery, Drupal, drupalSettings);
