<?php

namespace Drupal\exit_survey\Ajax;

use Drupal\Core\Ajax\CommandInterface;

/**
 * Base class for storage commands.
 *
 * @ingroup ajax
 */
class StorageAddCommand implements CommandInterface {

  /**
   * The key for storing the data in browser storage.
   *
   * @var string
   */
  protected $key;

  /**
   * Data to add or remove from browser storage.
   *
   * @var array
   */
  protected $data;

  /**
   * Which storage to use (local or session).
   *
   * @var string
   */
  protected $storage;

  /**
   * Constructs a storage command object.
   *
   * @param string $key
   *   The key for storing data in browser storage.
   * @param array $data
   *   Data to add to local storage.
   * @param string $storage
   *   Which storage to use.
   */
  public function __construct($key = 'Drupal.localstorage', array $data = [], $storage = 'local') {
    $this->key = $key;
    $this->data = $data;
    $this->storage = $storage;
  }

    /**
   * {@inheritdoc}
   */
  public function render() {
    return [
      'command' => 'storageAdd',
      'key' => $this->key,
      'data' => $this->data,
      'storage' => $this->storage,
    ];
  }


}
