<?php

declare(strict_types=1);

namespace Drupal\exit_survey\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\exit_survey\ExitSurveyInterface;
use Drupal\user\EntityOwnerTrait;

/**
 * Defines the exit survey entity class.
 *
 * @ContentEntityType(
 *   id = "exit_survey",
 *   label = @Translation("Exit survey"),
 *   label_collection = @Translation("Exit surveys"),
 *   label_singular = @Translation("exit survey"),
 *   label_plural = @Translation("exit surveys"),
 *   label_count = @PluralTranslation(
 *     singular = "@count exit surveys",
 *     plural = "@count exit surveys",
 *   ),
 *   bundle_label = @Translation("Exit survey type"),
 *   handlers = {
 *     "list_builder" = "Drupal\exit_survey\ExitSurveyListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "form" = {
 *       "add" = "Drupal\exit_survey\Form\ExitSurveyForm",
 *       "modal" = "Drupal\exit_survey\Form\ModalExistSurveyForm",
 *       "edit" = "Drupal\exit_survey\Form\ExitSurveyForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm",
 *       "delete-multiple-confirm" = "Drupal\Core\Entity\Form\DeleteMultipleForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\exit_survey\Routing\ExitSurveyHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "exit_survey",
 *   admin_permission = "administer exit_survey types",
 *   entity_keys = {
 *     "id" = "id",
 *     "bundle" = "bundle",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *     "owner" = "uid",
 *   },
 *   links = {
 *     "collection" = "/admin/content/exit-survey",
 *     "add-form" = "/exit-survey/add/{exit_survey_type}",
 *     "add-page" = "/exit-survey/add",
 *     "canonical" = "/exit-survey/{exit_survey}",
 *     "edit-form" = "/exit-survey/{exit_survey}",
 *     "delete-form" = "/exit-survey/{exit_survey}/delete",
 *     "delete-multiple-form" = "/admin/content/exit-survey/delete-multiple",
 *   },
 *   bundle_entity_type = "exit_survey_type",
 *   field_ui_base_route = "entity.exit_survey_type.edit_form",
 * )
 */
final class ExitSurvey extends ContentEntityBase implements ExitSurveyInterface {

  use EntityChangedTrait;
  use EntityOwnerTrait;

  /**
   * {@inheritdoc}
   */
  public function preSave(EntityStorageInterface $storage): void {
    parent::preSave($storage);
    if (!$this->getOwnerId()) {
      // If no owner has been set explicitly, make the anonymous user the owner.
      $this->setOwnerId(0);
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {

    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['uid'] = BaseFieldDefinition::create('entity_reference')
    ->setLabel(t('Author'))
    ->setSetting('target_type', 'user')
    ->setDefaultValueCallback(self::class . '::getDefaultEntityOwner');

    $fields['label'] = BaseFieldDefinition::create('string')
    ->setLabel(t('Label'));

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Authored on'))
      ->setDescription(t('The time that the exit survey was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the exit survey was last edited.'));

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Status'));

    return $fields;
  }

}
