<?php

declare(strict_types=1);

namespace Drupal\exit_survey\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBundleBase;

/**
 * Defines the Exit survey type configuration entity.
 *
 * @ConfigEntityType(
 *   id = "exit_survey_type",
 *   label = @Translation("Exit survey type"),
 *   label_collection = @Translation("Exit survey types"),
 *   label_singular = @Translation("exit survey type"),
 *   label_plural = @Translation("exit surveys types"),
 *   label_count = @PluralTranslation(
 *     singular = "@count exit surveys type",
 *     plural = "@count exit surveys types",
 *   ),
 *   handlers = {
 *     "form" = {
 *       "add" = "Drupal\exit_survey\Form\ExitSurveyTypeForm",
 *       "edit" = "Drupal\exit_survey\Form\ExitSurveyTypeForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     },
 *     "list_builder" = "Drupal\exit_survey\ExitSurveyTypeListBuilder",
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   admin_permission = "administer exit_survey types",
 *   bundle_of = "exit_survey",
 *   config_prefix = "exit_survey_type",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "add-form" = "/admin/structure/exit_survey_types/add",
 *     "edit-form" = "/admin/structure/exit_survey_types/manage/{exit_survey_type}",
 *     "delete-form" = "/admin/structure/exit_survey_types/manage/{exit_survey_type}/delete",
 *     "collection" = "/admin/structure/exit_survey_types",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "uuid",
 *   },
 * )
 */
final class ExitSurveyType extends ConfigEntityBundleBase {

  /**
   * The machine name of this exit survey type.
   */
  protected string $id;

  /**
   * The human-readable name of the exit survey type.
   */
  protected string $label;

}
