<?php

declare(strict_types=1);

namespace Drupal\exit_survey\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\CloseDialogCommand;
use Drupal\Core\Ajax\MessageCommand;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\exit_survey\Ajax\StorageAddCommand;
use Symfony\Component\HttpFoundation\Cookie;

/**
 * Form controller for the exit survey entity edit forms.
 */
final class ModalExistSurveyForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $form['actions']['submit']['#ajax'] = [
      'callback' => '::ajaxSubmit',
    ];
    $form['actions']['submit']['#value'] = $this->t('Send');
    $form['actions']['cancel'] = [
      '#type' => 'button',
      '#value' => $this->t('Close'),
      '#attributes' => [
        'onclick' => "Drupal.dialog(document.getElementById('drupal-modal')).close(); return false;",
      ],
    ];
    return $form;
  }

  public function ajaxSubmit(&$form, FormStateInterface $form_state): AjaxResponse
  {
    $response = new AjaxResponse();
    $response->addCommand(new MessageCommand('Thanks for your feedback!'));
    $response->addCommand(new StorageAddCommand('Drupal.exit_survey.submitted'));
    $response->addCommand(new CloseDialogCommand());
    // ToDo add redirect when form is an "add-form"
    return $response;
  }

}
